@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/support.tcl,v $
-# $Date: 1998/03/25 11:12:43 $
-# $Revision: 1.18.1.34 $
+# $Date: 1998/05/06 11:41:26 $
+# $Revision: 1.18.1.36 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -162,7 +162,7 @@ proc mainWindow {} {
     wm resizable $w 1 0 
     grid columnconfigure $w 1 -weight 1
     frame $w.vinfo -relief groove -borderwidth 3
-    set img [image create photo -file gifs/zlogo.gif]
+    set img [image create photo -file [file join gifs zlogo.gif]]
     label $w.vinfo.vlogo -image $img -relief groove -borderwidth 3
     label $w.vinfo.version -text Zircon
     label $w.vinfo.patch -text "Version $Version Patchlevel $Patchlevel"
@@ -178,7 +178,7 @@ proc mainWindow {} {
 proc makeEntry {w wn txt var row cmd} {
     global NoGUI
     if {!$NoGUI} {
-        button $w.$wn -text $txt
+        label $w.$wn -text $txt -relief raised
 	entry $w.${wn}entry -textvariable $var
     }
     $cmd
@@ -323,6 +323,7 @@ proc show {w file} {
     toplevel $w
     wm title $w "Zircon $file"
     grid columnconfigure $w 0 -weight 1
+    grid rowconfigure $w 0 -weight 1
     scrollbar $w.vs -command "$w.txt yview"
     scrollbar $w.hs -orient horizontal -command "$w.txt xview"
     text $w.txt -width 80 -height 24 -yscrollcommand "$w.vs set" \
