@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1998/06/09 09:25:37 $
-# $Revision: 1.18.1.95 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Control.tcl,v $
+# $Date: 1998/06/24 11:13:36 $
+# $Revision: 1.18.1.96 $
 #
 #
 package provide zircon 1.18
@@ -10,17 +10,19 @@ proc busyFlag {net} { $net configure -busy [expr ![$net busy]] }
 #
 proc control_configure {this args} { confObj $this $args }
 #
-#proc control_call {this op args} {
-#    upvar #0 $this cdata
-#    if {[info exists cdata($op)]} {return $cdata($op)}
-#    return [eval control_$op $this $args]
-#}
-#
 proc control_close {this} {
     $this flagState disabled
     [$this friends] close
 }
 #
+proc control_lag {this secs} {
+    set frm [winfo parent [$this window]].exp
+    if {![winfo exists $frm.lag]} {
+        grid [label $frm.lag -text {} -width 7] -row 0 -column 2
+    }
+    $frm.lag configure -text "$secs secs"
+}
+#
 proc control_pickServer {this srv} { [$this net] changeServer $srv }
 #
 proc control_showServer {this srv args} {
