@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/IRC.tcl,v $
-# $Date: 1998/05/20 09:10:11 $
-# $Revision: 1.18.1.53 $
+# $Source: /home/nlfm/Zircon/lib/RCS/IRC.tcl,v $
+# $Date: 1998/06/24 11:13:38 $
+# $Revision: 1.18.1.54 $
 #
 package provide zircon 1.18
 #
@@ -25,7 +25,7 @@ proc ctcpAnswer {net usr nk cp} {
 #
 proc ircERROR {net prefix param pargs} { $net error $prefix $param $pargs }
 #
-proc ircPONG {net prefix param pargs} { $net configure -pinged 0 }
+proc ircPONG {net prefix param pargs} { $net handlePong }
 #
 proc mungNotice {msg} {
     if {[regexp \
