@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/06/24 11:13:41 $
-# $Revision: 1.18.1.142 $
+# $Date: 1998/06/25 10:55:52 $
+# $Revision: 1.18.1.143 $
 #
 package provide zircon 1.18
 #
@@ -282,16 +282,15 @@ proc net_startIRC {this srv args} {
       -hostid $srv -motdSeen 0 closing {}
     set ctl [$this control]
     set ost [$ctl openState]
-    set ports [$srv port]
+    set ports [$srv selport]
     set noret 0
     switch -- $args {} {} -noretry { set noret 1} default {
-	switch [set pt [lindex $args 0]] [lindex $ports 0] {} default {
-	   set ports $pt
-	}
+	$srv configure +port [lindex $args 0]
     }
     set enc [$srv encoding]
     while {1} {
-	foreach port $ports {
+	while {1} {
+	    set port [$srv selport]
 	    $ctl showServer $srv $port
 	    $this inform "Connecting to port $port of server $server"
 	    update idletasks
@@ -343,6 +342,7 @@ proc net_startIRC {this srv args} {
 	        return 0
 	    }
 	}
+	switch {} [$srv nextPort] break
     }
 }
 #
@@ -398,7 +398,7 @@ proc net_changeServerPort {this srv prt} {
 	    return
 	}
     }
-    $this changeServer [Server $srv -port $prt]
+    $this changeServer [Server $srv +port $prt]
 }
 #
 proc net_changeServer {this srv args} {
