@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Netspace.tcl,v $
-# $Date: 1998/02/23 09:21:24 $
-# $Revision: 1.18.1.20 $
+# $Date: 1998/06/05 19:34:13 $
+# $Revision: 1.18.1.21 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -67,6 +67,7 @@ proc nsDelete {name} {
     global zircon
     filedirdel [file join $zircon(prefdir) netspaces $name]
     delFromNsM $name
+    delFromConf $name
 }
 #
 proc nsClone {name} {
@@ -113,10 +114,11 @@ proc nsUnload {name} {
 		return
 	    }
 	    if {![file exists [file join $zircon(prefdir) netspaces $name]]} {
-		delFromNsM [$x name]
+		delFromNsM $name
 	    } {
 		setUnload $name disabled
 	    }
+	    delFromConf $name
 	    $x delete
 	    break
 	}
