@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Server.tcl,v $
-# $Date: 1998/02/27 10:35:59 $
-# $Revision: 1.18.1.27 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Server.tcl,v $
+# $Date: 1998/06/25 10:55:54 $
+# $Revision: 1.18.1.28 $
 #
 #
 package provide zircon 1.18
@@ -25,10 +25,25 @@ proc Server {name args} {
     return $this
 }
 #
+proc server_nextPort {this} {
+    upvar #0 $this sdata
+    set x [lsearch $sdata(port) $sdata(selport)]
+    switch {} [set np [lindex $ndata(port) [incr x]]] { return {} }
+    set sdata(selport) $np
+    return $np
+}
+#
 proc server_configure {this args} {
     upvar #0 $this sdata
     foreach {opt val} $args {
 	switch -exact -- $opt {
+	+port {
+	    if {![listmember $sdata(port) $val]} {
+	        lappend sdata(list) $port
+		set sdata(port) [lsort -integer $sdata(port)]
+	    }
+	    set sdata(selport) $val
+	}
 	-port {
 		set sdata(port) {}
 		foreach x $val {
@@ -46,6 +61,7 @@ proc server_configure {this args} {
 		    }
 		}
 		set sdata(port) [lsort -integer $sdata(port)]
+		set sdata(selport) [lindex $sdata(port) 0]
 	    }
 	-host { set sdata(host) [string tolower $val] }
 	default { set sdata([string range $opt 1 end]) $val }
