@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Windows.tcl,v $
-# $Date: 1997/02/28 13:36:31 $
-# $Revision: 1.18.1.4 $
+# $Date: 1998/02/09 16:56:59 $
+# $Revision: 1.18.1.5 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -14,7 +14,7 @@ package provide windows 1.18
 #
 proc tmpdir {} {
     global env zircon
-    if [info exists zircon(tmp)] { return $zircon(tmp) }
+    if {[info exists zircon(tmp)]} { return $zircon(tmp) }
     return $env(TEMP)
 }
 #
