@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/config.tcl,v $
-# $Date: 1998/06/08 21:37:39 $
-# $Revision: 1.18.1.31 $
+# $Source: /home/nlfm/Zircon/lib/RCS/config.tcl,v $
+# $Date: 1998/06/25 09:32:33 $
+# $Revision: 1.18.1.32 $
 #
 package provide zircon 1.18
 #
@@ -122,8 +122,10 @@ proc confCopyBack {net which} {
 		}
 		global defChan
 	        set df $defChan($net)
-	        [$net info] configure -history [$df history] \
-	          -scrollback [$df scrollback] -closetime [$df closetime]
+		switch {} [set inf [$net info]] {} default {
+	            $inf configure -history [$df history] \
+	              -scrollback [$df scrollback] -closetime [$df closetime]
+		}
 	    }
 	}
     }
