@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/initial.tcl,v $
-# $Date: 1998/04/29 11:44:33 $
-# $Revision: 1.18.1.165 $
+# $Date: 1998/05/28 09:33:21 $
+# $Revision: 1.18.1.169 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -11,14 +11,6 @@
 #
 package provide zircon 1.18
 #
-#
-set cfgv {showLocal showPublic showPrivate topicOnly
-  minMembers friendsStyle helpService friendsOn monitorTime
-  verboseCTCP noRefresh killPath showFriends noConfirm toInfo
-  noPopup popInfo topicPattern listPattern wallops srvmsg 
-  invisible notifyInterval testTime autoget autochat
-}
-#
 proc preferences {op val} {}
 #
 proc dispAd {msg} {
@@ -139,7 +131,7 @@ proc layout {net window geom} {
     uplevel #0 set zlayout($net,$window) $geom
 }
 #
-proc checkRE {exp} { return [expr {![catch {regexp $exp a}]}] }
+proc checkRE {exp} { return [expr {![catch {regexp -- $exp a}]}] }
 #
 proc helper {ptn cmd args} {
     global currentNet
@@ -184,7 +176,7 @@ proc InitImages {} {
 	set DIms($x) [image create photo -file [file join $f $x.gif]]
     }
     global zDIOff zDIOn zDIOff1 zDIOn1 zKeyGif zSpkGif zNSpkGif zII \
-      zNOII zLock zUnlock zLogo
+      zNOII zLock zUnlock zLogo zLog
     set zDIOff [image create photo -file [file join $f off.gif]]
     set zDIOn  [image create photo -file [file join $f on.gif]]
     set zDIOff1 [image create photo -file [file join $f off1.gif]]
@@ -196,6 +188,7 @@ proc InitImages {} {
     set zNOII [image create photo -file [file join $f noii.gif]]
     set zLock [image create photo -file [file join $f lock.gif]]
     set zUnlock [image create photo -file [file join $f unlock.gif]]
+    set zLog [image create photo -file [file join $f log.gif]]
     set zLogo [image create photo -file [file join $f zlogo.gif]]
     setupImages
 }
@@ -235,6 +228,7 @@ proc Initialise {} {
     set zWList {}
     set zWClose {}
     set zWInc 30000
+    InitConsts
 #
     set inexp1 {^([^ ]*) ([^ ]*)(( ([^:][^ ]*))*)( :(.*))?$}
     set inexp2 {^([^ ]*) ([^ ]*)(.*)?$}
@@ -331,6 +325,12 @@ Continue?}]} {
       <Control-h> <ButtonRelease-2>} {
 	bind ROText $x {}
     }
+    foreach x [bind Entry] { bind NEntry $x [bind Entry $x] }
+    bind NEntry <Key> {
+	notIdle %W
+	switch -glob -- %A { [0-9+-] { tkEntryInsert %W %A } }
+	break
+    }
     array set zircon "
 	meta		Meta
 	bellcmd		bell
@@ -397,7 +397,7 @@ Continue?}]} {
     if {$DEBUG} zDBGControl
     set ops 1
     foreach x {Font Foreground Background} {
-        switch {} [option get . operator$x {}] {} default {
+        switch {} [option get . operator$x Operator$x] {} default {
 	    set ops 0
 	    break
 	}
@@ -570,33 +570,6 @@ has changed - please re-save your preferences" warning 0 ok
     }
 }
 #
-# Configuration panel stuff
-#
-array set cVars {
-    Nicknames		{nicks}
-    IRCNames		{ircnames}
-    Servers	{}
-    DCC		{}
-    Messages	{}
-    Notices	{}
-    Chat	{}
-    Channels	{}
-    Friends	{showFriends friendsOn}
-    Ignores	{ignores}
-    Info	{showLocal showPublic showPrivate topicOnly minMembers \
-		 noConfirm toInfo popInfo verboseCTCP helpService \
-		 noPopup noRefresh killPath listPattern topicPattern \
-		 notifyInterval}
-}
-#
-set tabNames {Nicknames IRCNames Servers Channels Messages Notices Chat DCC Friends Ignores Info}
-#
-array set confData {
-    channel	{{{Auto Join} join} {{Pop Up} open} \
-		 {{Pop Down} close} {{On Menu} menu} {Draw draw} \
-		 {Jump jump} {Quiet quiet} {{Ignore Case} nocase}}
-}
-#
 proc versionCheck {} {
     global zircon
     set f [file join $zircon(prefdir) version]
