@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/main.tcl,v $
-# $Date: 1998/04/15 12:56:14 $
-# $Revision: 1.18.1.81 $
+# $Date: 1998/05/21 12:55:34 $
+# $Revision: 1.18.1.86 $
 #
 package provide zircon 1.18
 #
@@ -22,11 +22,11 @@ proc playBell {this tag} {
 }
 #
 proc setScroll {id txt win total window} {
-    upvar #0 $id cdata
-    if {$total > $cdata(scrollback)} {
-	incr total -$cdata(scrollback)
+    upvar #0 ${id}(scrollback) sb
+    if {$total > $sb} {
+	incr total -$sb
 	$txt delete 1.0 "1.0 + $total lines"
-	set total $cdata(scrollback)
+	set total $sb
     }
     $win set $total $window
 }
@@ -46,79 +46,6 @@ proc setState {name pick state} {
     }
 }
 #
-#	0 white       8 yellow
-#	1 black       9 lightgreen
-#	2 blue       10 cyan
-#	3 green      11 lightcyan
-#	4 red   12 lightblue
-#	5 brown      13 pink
-#	6 purple     14 grey
-#	7 orange     15 lightgrey
-#
-array set mIRCCol {
-    0 #ffffff	8 #ffff00
-    1 #000000	9 #80ff80
-    2 #000080	10 #008080
-    3 #00ff00	11 #00ffff
-    4 #ff0000   12 #0000ff
-    5 #808000	13 #ff00ff
-    6 #800080	14 #808080
-    7 #ffa500	15 #d3d3d3
-}
-#
-proc insertText {this name text tag} {
-    lappend taglist $tag
-    switch -glob -- $text "*\[\002\003\007\017\026\037\]*" {
-	set bellcnt 0
-	while {[regexp \
-	  "^(\[^\002\003\007\017\026\037\]*)(\[\002\003\007\017\026\037\])(.*)$" \
-	  $text match m1 ch text]} {
-	    $name insert end $m1 $taglist
-	    switch -- $ch {
-	    \002 { set spc @b@ }
-	    \007 {
-		    if {![set bl [[$this net] beeplimit]] || [incr bellcnt] < $bl} {
-		        if {![$this quiet]} { playBell $this $tag }
-		        $name insert end { } $taglist [[$this net] beep] \
-		          [concat $taglist @a@$tag] { } $taglist
-		    }
-		    continue
-		}
-	    \017 { set taglist {} ; lappend taglist $tag ; continue }
-	    \026 { set spc @v@ }
-	    \037 { set spc @u@ }
-	    \003 {
-		# colour stuff
-		    global mIRCCol
-		    if {[regexp {^([0-9][0-9]?)(,([0-9][0-9]?))?(.*)} \
-		      $text m fg bl bg text]} {
-		        switch {} [$this colour] continue
-			set tag [newName @c@]
-			regsub ^0 $fg {} fg
-			switch {} $fg { set fg 0 } \
-			  default {set fg [expr {$fg % 16}]}
-			$name tag configure $tag -foreground $mIRCCol($fg)
-			lappend taglist $tag
-			switch {} $bg {} default {
-			    regsub ^0 $bg {} bg
-			    switch {} $bg { set bg 0 } \
-			      default { set bg [expr {$bg % 16}]}
-			    $name tag configure $tag -background $mIRCCol($bg)
-			}
-		    } {
-			listkill taglist @c@*
-		    }
-		    continue
-		}
-	    }
-	    if {[set x [lsearch $taglist ${spc}*]] < 0} {
-		lappend taglist $spc$tag
-	    } {	set taglist [lreplace $taglist $x $x] }
-	}
-    }
-    $name insert end $text $taglist
-}
-#
 proc doNotice {net chan string} { 
     switch {} $string return
     if {![string compare nil [set cn [Channel :: find $chan $net]]] ||
@@ -128,7 +55,7 @@ proc doNotice {net chan string} {
 	$cn addText @me "- $string"
 	$cn addHist $string
     }
-    $net qSend NOTICE $chan :$string
+    $net q1Send "NOTICE $chan :$string"
 }
 #
 proc channelNotice {net chan args} {
@@ -151,12 +78,12 @@ proc channelJoin {net chan args} {
 #
 proc channelMode {net chan} {
     switch {} $chan return
-    $net qSend MODE :$chan
+    $net q1Send "MODE :$chan"
 }
 #
 proc channelWho {net chan} {
     switch {} $chan return
-    $net qSend WHO :$chan
+    $net q1Send "WHO :$chan"
 }
 #
 proc channelNames {net chan} {
@@ -165,7 +92,7 @@ proc channelNames {net chan} {
 	    $net q1Send NAMES
 	}
     } default {
-	$net qSend NAMES :$chan
+	$net q1Send "NAMES :$chan"
     }
 }
 
@@ -193,7 +120,7 @@ proc irc001 {net prefix param pargs} {
 	      [list [list password {} {} secret]] \
 	      [list ok [list $net OPER $nk]] [list cancel {}]
 	} default {
-	    $net qSend OPER $nk :$pw
+	    $net q1Send "OPER $nk :$pw"
 	}
     }
     foreach x {channels messages notices} {
@@ -317,13 +244,13 @@ proc irc303 {net prefix param pargs} {
 	}
 	eval $cmd
     }
-    foreach x $signInfo($net) {$net qSend USERHOST :[$x name]}
+    foreach x $signInfo($net) {$net q1Send "USERHOST :[$x name]"}
     foreach x $signons { handleOn $net ISON $x }
 }
 #
-proc who303 {net args} { foreach x $args { $net qSend WHOIS [colonLast $x] } }
+proc who303 {net args} { foreach x $args { $net q1Send "WHOIS [colonLast $x]" } }
 #
-proc was303 {net args} { foreach x $args { $net qSend WHOWAS [colonLast $x] } }
+proc was303 {net args} { foreach x $args { $net q1Send "WHOWAS [colonLast $x]" } }
 #
 proc irc305 {net prefix param pargs} { $net irc305 }
 #
