@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dccget.tcl,v $
-# $Date: 1998/04/22 08:57:06 $
-# $Revision: 1.18.1.8 $
+# $Date: 1998/05/21 13:38:54 $
+# $Revision: 1.18.1.9 $
 #
 package provide Dcc 1.18
 #
@@ -26,7 +26,7 @@ proc startGet {sk net file usr leng posn} {
 	if {[winfo exists .@dls$net]} { buildDCCList $net }
 	dccWindow $fd $usr Get $file
     }
-    close $sk
+    catch {close $sk}
 }
 } default {
 #
